@@ -1,3 +1,4 @@
+from .util import http_get
 import requests
 
 root_url = 'https://tryhackme.com'
@@ -22,8 +23,6 @@ class THM(object):
         #     if ('username' in credentials) and ('password' in credentials):
         #         self.__login(credentials)
 
-        print(self.get_stats())
-
     def get_stats(self) -> dict:
         """
         Returns public and cloneable room count and current user count
@@ -31,14 +30,22 @@ class THM(object):
         :return: Dict containing mentioned values
         """
 
-        path = f'{root_url}/api/getstats'
+        return http_get(self.session, f'{root_url}/api/getstats')
 
-        try:
-            r = self.session.get(path)
+    def get_leaderboard(self) -> list:
+        """
+        Returns the top 50 users from the all-time leaderboard
 
-            if r.status_code == 200:
-                return r.json()
-            else:
-                raise Exception('HTTP Response was not 200')
-        except Exception as err:
-            raise err
+        :return: List containing top 50 users
+        """
+
+        return http_get(self.session, f'{root_url}/api/leaderboards')['topUsers']
+
+    def get_monthly_leaderboard(self) -> list:
+        """
+        Returns the top 50 users from the monthly leaderboard
+
+        :return: List containing top 50 users
+        """
+
+        return http_get(self.session, f'{root_url}/api/leaderboards')['topUsersMonthly']
